;; Generated package description from csv-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "csv-mode" "1.27.0.20260505.161621" "Major mode for editing comma/char separated values" '((emacs "27.1") (cl-lib "0.5")) :commit "3a441a41a3b1d61c2a9c9f5f091cb38ba6b45d47" :url "https://elpa.gnu.org/packages/csv-mode.html" :authors '(("Francis J. Wright" . "F.J.Wright@qmul.ac.uk")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("convenience"))
